@@ -14,7 +14,8 @@ from conans.client.migrations import ClientMigrator
 from conans.client.output import ConanOutput, ScopedOutput
 from conans.client.profile_loader import read_profile, profile_from_args, \
     read_conaninfo_profile
-from conans.client.recorder.upload_recoder import UploadRecoder
+from conans.client.recorder.search_recorder import SearchRecorder
+from conans.client.recorder.upload_recoder import UploadRecorder
 from conans.client.remote_manager import RemoteManager
 from conans.client.remote_registry import RemoteRegistry
 from conans.client.rest.auth_manager import ConanApiAuthManager
@@ -29,7 +30,6 @@ from conans.errors import ConanException
 from conans.model.ref import ConanFileReference
 from conans.model.version import Version
 from conans.paths import get_conan_user_home, CONANINFO, BUILD_INFO
-from conans.search.search import DiskSearchManager
 from conans.util.env_reader import get_env
 from conans.util.files import save_files, exception_message_safe, mkdir
 from conans.util.log import configure_logger
@@ -45,6 +45,7 @@ from conans.client.cmd.user import users_clean, users_list, user_set
 from conans.client.importer import undo_imports
 from conans.client.cmd.export import cmd_export, export_alias
 from conans.unicode import get_cwd
+from conans.client.remover import ConanRemover
 
 
 default_manifest_folder = '.conan_manifests'
@@ -194,18 +195,15 @@ class ConanAPIV1(object):
             # Adjust global tool variables
             set_global_instances(out, requester)
 
-            # Get a search manager
-            search_manager = DiskSearchManager(client_cache)
-
             # Settings preprocessor
             if interactive is None:
                 interactive = not get_env("CONAN_NON_INTERACTIVE", False)
-            conan = ConanAPIV1(client_cache, user_io, get_conan_runner(), remote_manager, search_manager,
+            conan = ConanAPIV1(client_cache, user_io, get_conan_runner(), remote_manager,
                                settings_preprocessor, interactive=interactive)
 
         return conan, client_cache, user_io
 
-    def __init__(self, client_cache, user_io, runner, remote_manager, search_manager,
+    def __init__(self, client_cache, user_io, runner, remote_manager,
                  _settings_preprocessor, interactive=True):
         assert isinstance(user_io, UserIO)
         assert isinstance(client_cache, ClientCache)
@@ -213,7 +211,6 @@ class ConanAPIV1(object):
         self._user_io = user_io
         self._runner = runner
         self._remote_manager = remote_manager
-        self._search_manager = search_manager
         self._settings_preprocessor = _settings_preprocessor
         self._registry = RemoteRegistry(self._client_cache.registry, self._user_io.out)
 
@@ -223,7 +220,7 @@ class ConanAPIV1(object):
     def _init_manager(self, action_recorder):
         """Every api call gets a new recorder and new manager"""
         return ConanManager(self._client_cache, self._user_io, self._runner,
-                            self._remote_manager, self._search_manager,
+                            self._remote_manager,
                             self._settings_preprocessor, action_recorder, self._registry)
 
     @api_method
@@ -631,12 +628,9 @@ class ConanAPIV1(object):
     @api_method
     def remove(self, pattern, query=None, packages=None, builds=None, src=False, force=False,
                remote=None, outdated=False):
-
-        recorder = ActionRecorder()
-        manager = self._init_manager(recorder)
-        manager.remove(pattern, package_ids_filter=packages, build_ids=builds,
-                       src=src, force=force, remote_name=remote, packages_query=query,
-                       outdated=outdated)
+        remover = ConanRemover(self._client_cache, self._remote_manager, self._user_io, self._registry)
+        remover.remove(pattern, remote, src, builds, packages, force=force,
+                       packages_query=query, outdated=outdated)
 
     @api_method
     def copy(self, reference, user_channel, force=False, packages=None):
@@ -675,14 +669,45 @@ class ConanAPIV1(object):
 
     @api_method
     def search_recipes(self, pattern, remote=None, case_sensitive=False):
+        recorder = SearchRecorder()
         search = Search(self._client_cache, self._remote_manager, self._registry)
-        return search.search_recipes(pattern, remote, case_sensitive)
+
+        try:
+            references = search.search_recipes(pattern, remote, case_sensitive)
+        except ConanException as exc:
+            recorder.error = True
+            exc.info = recorder.get_info()
+            raise
+
+        for remote, refs in references.items():
+            for ref in refs:
+                recorder.add_recipe(str(remote), str(ref), with_packages=False)
+        return recorder.get_info()
 
     @api_method
     def search_packages(self, reference, query=None, remote=None, outdated=False):
+        recorder = SearchRecorder()
         search = Search(self._client_cache, self._remote_manager, self._registry)
-        return search.search_packages(reference, remote, query=query,
-                                      outdated=outdated)
+
+        try:
+            ordered_packages, ref, recipe_hash = search.search_packages(reference, remote,
+                                                                        query=query,
+                                                                        outdated=outdated)
+        except ConanException as exc:
+            recorder.error = True
+            exc.info = recorder.get_info()
+            raise
+
+        recorder.add_recipe(str(remote), str(ref))
+        if ordered_packages:
+            for package_id, properties in ordered_packages.items():
+                package_recipe_hash = properties.get("recipe_hash", None)
+                recorder.add_package(str(remote), str(reference), package_id,
+                                     properties.get("options", []),
+                                     properties.get("settings", []),
+                                     properties.get("full_requires", []),
+                                     recipe_hash != package_recipe_hash)
+        return recorder.get_info()
 
     @api_method
     def upload(self, pattern, package=None, remote=None, all_packages=False, force=False,
@@ -691,7 +716,7 @@ class ConanAPIV1(object):
         """ Uploads a package recipe and the generated binary packages to a specified remote
         """
 
-        recorder = UploadRecoder()
+        recorder = UploadRecorder()
 
         if force and no_overwrite:
             exc = ConanException("'no_overwrite' argument cannot be used together with 'force'")
