@@ -237,7 +237,9 @@ endmacro()
 macro(conan_set_std)
   # Do not warn "Manually-specified variables were not used by the project"
   set(ignorevar "${CONAN_STD_CXX_FLAG}${CONAN_CMAKE_CXX_STANDARD}${CONAN_CMAKE_CXX_EXTENSIONS}")
-  if (CMAKE_VERSION VERSION_LESS "3.1")
+  # TODO: Check version where CMake supports 20, still not released
+  if (CMAKE_VERSION VERSION_LESS "3.1" OR "${CONAN_CMAKE_CXX_STANDARD}" STREQUAL "20"
+                                       OR "${CONAN_CMAKE_CXX_STANDARD}" STREQUAL "gnu20")
     if(CONAN_STD_CXX_FLAG)
       message(STATUS "Conan setting CXX_FLAGS flags: ${CONAN_STD_CXX_FLAG}")
       set(CMAKE_CXX_FLAGS "-std=${CONAN_STD_CXX_FLAG} ${CMAKE_CXX_FLAGS}")
@@ -269,6 +271,13 @@ macro(conan_set_rpath)
     endif()
 endmacro()
 
+macro(conan_set_fpic)
+    if(DEFINED CONAN_CMAKE_POSITION_INDEPENDENT_CODE)
+        message(STATUS "Conan: Adjusting fPIC flag (${CONAN_CMAKE_POSITION_INDEPENDENT_CODE})")
+        set(CMAKE_POSITION_INDEPENDENT_CODE ${CONAN_CMAKE_POSITION_INDEPENDENT_CODE})
+    endif()
+endmacro()
+
 macro(conan_output_dirs_setup)
     set(CMAKE_RUNTIME_OUTPUT_DIRECTORY ${CMAKE_CURRENT_BINARY_DIR}/bin)
     set(CMAKE_RUNTIME_OUTPUT_DIRECTORY_RELEASE ${CMAKE_RUNTIME_OUTPUT_DIRECTORY})
@@ -490,7 +499,7 @@ endmacro()
 
 cmake_macros = """
 macro(conan_basic_setup)
-    set(options TARGETS NO_OUTPUT_DIRS SKIP_RPATH KEEP_RPATHS SKIP_STD)
+    set(options TARGETS NO_OUTPUT_DIRS SKIP_RPATH KEEP_RPATHS SKIP_STD SKIP_FPIC)
     cmake_parse_arguments(ARGUMENTS "${options}" "${oneValueArgs}" "${multiValueArgs}" ${ARGN} )
     if(CONAN_EXPORTED)
         message(STATUS "Conan: called by CMake conan helper")
@@ -520,6 +529,9 @@ macro(conan_basic_setup)
         message(STATUS "Conan: Adjusting language standard")
         conan_set_std()
     endif()
+    if(NOT ARGUMENTS_SKIP_FPIC)
+        conan_set_fpic()
+    endif()
     conan_set_vs_runtime()
     conan_set_libcxx()
     conan_set_find_paths()
@@ -615,6 +627,7 @@ macro(conan_basic_setup)
     conan_set_vs_runtime()
     conan_set_libcxx()
     conan_set_find_paths()
+    conan_set_fpic()
 endmacro()
 
 macro(conan_set_vs_runtime)
